@@ -1,13 +1,15 @@
 import logging
 import os
+
 from tutum.api import auth
-from tutum.api.application import Application
+from tutum.api.cluster import Cluster
 from tutum.api.container import Container
 from tutum.api.registry import Registry
 from tutum.api.image import Image
 from tutum.api.exceptions import TutumApiError, TutumAuthError
 
-__version__ = '0.7.3'
+
+__version__ = '0.7.5'
 
 #: The username used to authenticate with the API
 user = auth.load_from_file()[0] or os.environ.get('TUTUM_USER', None)
