@@ -1,3 +1,4 @@
+import json
 from base import RESTModel
 
 
@@ -22,6 +23,14 @@ class Container(RESTModel):
         """
         return self._perform_action("stop")
 
+    def redeploy(self, tag=None):
+        """Redeploy the container in Tutum.
+
+        :returns: bool -- whether or not the operation succeeded
+        :raises: TutumApiError
+        """
+        return self._perform_action("redeploy", data=json.dumps({"tag": tag}))
+
     @property
     def logs(self):
         """Fetches and returns the logs for the container from Tutum
